"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def label(
    hub, ctx, name: str, labels: List, parameter_version: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    A parameter label is a user-defined alias to help you manage different versions of a parameter. When you modify a parameter, Amazon Web Services Systems Manager automatically saves a new version and increments the version number by one. A label can help you remember the purpose of a parameter when there are multiple versions.  Parameter labels have the following requirements and restrictions.   A version of a parameter can have a maximum of 10 labels.   You can't attach the same label to different versions of the same parameter. For example, if version 1 has the label Production, then you can't attach Production to version 2.   You can move a label from one version of a parameter to another.   You can't create a label when you create a new parameter. You must attach a label to a specific version of a parameter.   If you no longer want to use a parameter label, then you can either delete it or move it to a different version of a parameter.   A label can have a maximum of 100 characters.   Labels can contain letters (case sensitive), numbers, periods (.), hyphens (-), or underscores (_).   Labels can't begin with a number, "aws" or "ssm" (not case sensitive). If a label fails to meet these requirements, then the label isn't associated with a parameter and the system displays it in the list of InvalidLabels.

    Args:
        name(str): The parameter name on which you want to attach one or more labels.
        parameter_version(int, optional): The specific version of the parameter on which you want to attach one or more labels. If no version is specified, the system attaches the label to the latest version. Defaults to None.
        labels(List): One or more labels to attach to the specified parameter version.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.parameter.version.label(ctx, name=value, labels=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.parameter.version.label name=value, labels=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="label_parameter_version",
        op_kwargs={
            "Name": name,
            "ParameterVersion": parameter_version,
            "Labels": labels,
        },
    )


async def unlabel(hub, ctx, name: str, parameter_version: int, labels: List) -> Dict:
    r"""
    **Autogenerated function**

    Remove a label or labels from a parameter.

    Args:
        name(str): The name of the parameter from which you want to delete one or more labels.
        parameter_version(int): The specific version of the parameter which you want to delete one or more labels from. If it isn't present, the call will fail.
        labels(List): One or more labels to delete from the specified parameter version.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.parameter.version.unlabel(
                ctx, name=value, parameter_version=value, labels=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.parameter.version.unlabel name=value, parameter_version=value, labels=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="unlabel_parameter_version",
        op_kwargs={
            "Name": name,
            "ParameterVersion": parameter_version,
            "Labels": labels,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    gateway_route_name: str,
    mesh_name: str,
    spec: Dict,
    virtual_gateway_name: str,
    client_token: str = None,
    mesh_owner: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a gateway route. A gateway route is attached to a virtual gateway and routes traffic to an existing virtual service. If a route matches a request, it can distribute traffic to a target virtual service. For more information about gateway routes, see Gateway routes.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Up to 36 letters, numbers, hyphens, and underscores are allowed. Defaults to None.
        gateway_route_name(str): The name to use for the gateway route.
        mesh_name(str): The name of the service mesh to create the gateway route in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then the account that you specify must share the mesh with your account before you can create the resource in the service mesh. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        spec(Dict): The gateway route specification to apply.
        tags(List, optional): Optional metadata that you can apply to the gateway route to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you define. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters. Defaults to None.
        virtual_gateway_name(str): The name of the virtual gateway to associate the gateway route with. If the virtual gateway is in a shared mesh, then you must be the owner of the virtual gateway resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.gateway_route.create(
                ctx,
                gateway_route_name=value,
                mesh_name=value,
                spec=value,
                virtual_gateway_name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.gateway_route.create gateway_route_name=value, mesh_name=value, spec=value, virtual_gateway_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="create_gateway_route",
        op_kwargs={
            "clientToken": client_token,
            "gatewayRouteName": gateway_route_name,
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "spec": spec,
            "tags": tags,
            "virtualGatewayName": virtual_gateway_name,
        },
    )


async def delete(
    hub,
    ctx,
    gateway_route_name: str,
    mesh_name: str,
    virtual_gateway_name: str,
    mesh_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing gateway route.

    Args:
        gateway_route_name(str): The name of the gateway route to delete.
        mesh_name(str): The name of the service mesh to delete the gateway route from.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        virtual_gateway_name(str): The name of the virtual gateway to delete the route from.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.gateway_route.delete(
                ctx, gateway_route_name=value, mesh_name=value, virtual_gateway_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.gateway_route.delete gateway_route_name=value, mesh_name=value, virtual_gateway_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="delete_gateway_route",
        op_kwargs={
            "gatewayRouteName": gateway_route_name,
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "virtualGatewayName": virtual_gateway_name,
        },
    )


async def describe(
    hub,
    ctx,
    gateway_route_name: str,
    mesh_name: str,
    virtual_gateway_name: str,
    mesh_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes an existing gateway route.

    Args:
        gateway_route_name(str): The name of the gateway route to describe.
        mesh_name(str): The name of the service mesh that the gateway route resides in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        virtual_gateway_name(str): The name of the virtual gateway that the gateway route is associated with.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.gateway_route.describe(
                ctx, gateway_route_name=value, mesh_name=value, virtual_gateway_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.gateway_route.describe gateway_route_name=value, mesh_name=value, virtual_gateway_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="describe_gateway_route",
        op_kwargs={
            "gatewayRouteName": gateway_route_name,
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "virtualGatewayName": virtual_gateway_name,
        },
    )


async def list_all(
    hub,
    ctx,
    mesh_name: str,
    virtual_gateway_name: str,
    limit: int = None,
    mesh_owner: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of existing gateway routes that are associated to a virtual gateway.

    Args:
        limit(int, optional): The maximum number of results returned by ListGatewayRoutes in paginated output. When you use this parameter, ListGatewayRoutes returns only limit results in a single page along with a nextToken response element. You can see the remaining results of the initial request by sending another ListGatewayRoutes request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, ListGatewayRoutes returns up to 100 results and a nextToken value if applicable. Defaults to None.
        mesh_name(str): The name of the service mesh to list gateway routes in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated ListGatewayRoutes request where limit was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. Defaults to None.
        virtual_gateway_name(str): The name of the virtual gateway to list gateway routes in.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.gateway_route.list_all(
                ctx, mesh_name=value, virtual_gateway_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.gateway_route.list_all mesh_name=value, virtual_gateway_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="list_gateway_routes",
        op_kwargs={
            "limit": limit,
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "nextToken": next_token,
            "virtualGatewayName": virtual_gateway_name,
        },
    )


async def update(
    hub,
    ctx,
    gateway_route_name: str,
    mesh_name: str,
    spec: Dict,
    virtual_gateway_name: str,
    client_token: str = None,
    mesh_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing gateway route that is associated to a specified virtual gateway in a service mesh.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Up to 36 letters, numbers, hyphens, and underscores are allowed. Defaults to None.
        gateway_route_name(str): The name of the gateway route to update.
        mesh_name(str): The name of the service mesh that the gateway route resides in.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.
        spec(Dict): The new gateway route specification to apply. This overwrites the existing data.
        virtual_gateway_name(str): The name of the virtual gateway that the gateway route is associated with.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.gateway_route.update(
                ctx,
                gateway_route_name=value,
                mesh_name=value,
                spec=value,
                virtual_gateway_name=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.gateway_route.update gateway_route_name=value, mesh_name=value, spec=value, virtual_gateway_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="update_gateway_route",
        op_kwargs={
            "clientToken": client_token,
            "gatewayRouteName": gateway_route_name,
            "meshName": mesh_name,
            "meshOwner": mesh_owner,
            "spec": spec,
            "virtualGatewayName": virtual_gateway_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    gateway_arn: str,
    disk_id: str,
    preserve_existing_data: bool,
    target_name: str,
    network_interface_id: str,
    snapshot_id: str = None,
    kms_encrypted: bool = None,
    kms_key: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a volume on a specified gateway. This operation is only supported in the stored volume gateway type. The size of the volume to create is inferred from the disk size. You can choose to preserve existing data on the disk, create volume from an existing snapshot, or create an empty volume. If you choose to create an empty gateway volume, then any existing data on the disk is erased. In the request, you must specify the gateway and the disk information on which you are creating the volume. In response, the gateway creates the volume and returns volume information such as the volume Amazon Resource Name (ARN), its size, and the iSCSI target ARN that initiators can use to connect to the volume target.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        disk_id(str): The unique identifier for the gateway local disk that is configured as a stored volume. Use ListLocalDisks to list disk IDs for a gateway.
        snapshot_id(str, optional): The snapshot ID (e.g., "snap-1122aabb") of the snapshot to restore as the new stored volume. Specify this field if you want to create the iSCSI storage volume from a snapshot; otherwise, do not include this field. To list snapshots for your account use DescribeSnapshots in the Amazon Elastic Compute Cloud API Reference. Defaults to None.
        preserve_existing_data(bool): Set to true if you want to preserve the data on the local disk. Otherwise, set to false to create an empty volume. Valid Values: true | false .
        target_name(str): The name of the iSCSI target used by an initiator to connect to a volume and used as a suffix for the target ARN. For example, specifying TargetName as myvolume results in the target ARN of arn:aws:storagegateway:us-east-2:111122223333:gateway/sgw-12A3456B/target/iqn.1997-05.com.amazon:myvolume. The target name must be unique across all volumes on a gateway. If you don't specify a value, Storage Gateway uses the value that was previously used for this volume as the new target name.
        network_interface_id(str): The network interface of the gateway on which to expose the iSCSI target. Only IPv4 addresses are accepted. Use DescribeGatewayInformation to get a list of the network interfaces available on a gateway. Valid Values: A valid IP address.
        kms_encrypted(bool, optional): Set to true to use Amazon S3 server-side encryption with your own KMS key, or false to use a key managed by Amazon S3. Optional. Valid Values: true | false . Defaults to None.
        kms_key(str, optional): The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used for Amazon S3 server-side encryption. Storage Gateway does not support asymmetric CMKs. This value can only be set when KMSEncrypted is true. Optional. Defaults to None.
        tags(List, optional): A list of up to 50 tags that can be assigned to a stored volume. Each tag is a key-value pair.  Valid characters for key and value are letters, spaces, and numbers representable in UTF-8 format, and the following special characters: + - = . _ : / @. The maximum length of a tag's key is 128 characters, and the maximum length for a tag's value is 256. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.stored_iscsi_volume.create(
                ctx,
                gateway_arn=value,
                disk_id=value,
                preserve_existing_data=value,
                target_name=value,
                network_interface_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.stored_iscsi_volume.create gateway_arn=value, disk_id=value, preserve_existing_data=value, target_name=value, network_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="create_stored_iscsi_volume",
        op_kwargs={
            "GatewayARN": gateway_arn,
            "DiskId": disk_id,
            "SnapshotId": snapshot_id,
            "PreserveExistingData": preserve_existing_data,
            "TargetName": target_name,
            "NetworkInterfaceId": network_interface_id,
            "KMSEncrypted": kms_encrypted,
            "KMSKey": kms_key,
            "Tags": tags,
        },
    )


async def describe_all(hub, ctx, volume_ar_ns: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns the description of the gateway volumes specified in the request. The list of gateway volumes in the request must be from one gateway. In the response, Storage Gateway returns volume information sorted by volume ARNs. This operation is only supported in stored volume gateway type.

    Args:
        volume_ar_ns(List): An array of strings where each string represents the Amazon Resource Name (ARN) of a stored volume. All of the specified stored volumes must be from the same gateway. Use ListVolumes to get volume ARNs for a gateway.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.stored_iscsi_volume.describe_all(
                ctx, volume_ar_ns=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.stored_iscsi_volume.describe_all volume_ar_ns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="describe_stored_iscsi_volumes",
        op_kwargs={"VolumeARNs": volume_ar_ns},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    attribute_definitions: List,
    table_name: str,
    key_schema: List,
    local_secondary_indexes: List = None,
    global_secondary_indexes: List = None,
    billing_mode: str = None,
    provisioned_throughput: Dict = None,
    stream_specification: Dict = None,
    sse_specification: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    The CreateTable operation adds a new table to your account. In an AWS account, table names must be unique within each Region. That is, you can have two tables with same name if you create the tables in different Regions.  CreateTable is an asynchronous operation. Upon receiving a CreateTable request, DynamoDB immediately returns a response with a TableStatus of CREATING. After the table is created, DynamoDB sets the TableStatus to ACTIVE. You can perform read and write operations only on an ACTIVE table.  You can optionally define secondary indexes on the new table, as part of the CreateTable operation. If you want to create multiple tables with secondary indexes on them, you must create the tables sequentially. Only one table with secondary indexes can be in the CREATING state at any given time. You can use the DescribeTable action to check the table status.

    Args:
        attribute_definitions(List): An array of attributes that describe the key schema for the table and indexes.
        table_name(str): The name of the table to create.
        key_schema(List): Specifies the attributes that make up the primary key for a table or an index. The attributes in KeySchema must also be defined in the AttributeDefinitions array. For more information, see Data Model in the Amazon DynamoDB Developer Guide. Each KeySchemaElement in the array is composed of:    AttributeName - The name of this key attribute.    KeyType - The role that the key attribute will assume:    HASH - partition key    RANGE - sort key      The partition key of an item is also known as its hash attribute. The term "hash attribute" derives from the DynamoDB usage of an internal hash function to evenly distribute data items across partitions, based on their partition key values. The sort key of an item is also known as its range attribute. The term "range attribute" derives from the way DynamoDB stores items with the same partition key physically close together, in sorted order by the sort key value.  For a simple primary key (partition key), you must provide exactly one element with a KeyType of HASH. For a composite primary key (partition key and sort key), you must provide exactly two elements, in this order: The first element must have a KeyType of HASH, and the second element must have a KeyType of RANGE. For more information, see Working with Tables in the Amazon DynamoDB Developer Guide.
        local_secondary_indexes(List, optional): One or more local secondary indexes (the maximum is 5) to be created on the table. Each index is scoped to a given partition key value. There is a 10 GB size limit per partition key value; otherwise, the size of a local secondary index is unconstrained. Each local secondary index in the array includes the following:    IndexName - The name of the local secondary index. Must be unique only for this table.     KeySchema - Specifies the key schema for the local secondary index. The key schema must begin with the same partition key as the table.    Projection - Specifies attributes that are copied (projected) from the table into the index. These are in addition to the primary key attributes and index key attributes, which are automatically projected. Each attribute specification is composed of:    ProjectionType - One of the following:    KEYS_ONLY - Only the index and primary keys are projected into the index.    INCLUDE - Only the specified table attributes are projected into the index. The list of projected attributes is in NonKeyAttributes.    ALL - All of the table attributes are projected into the index.      NonKeyAttributes - A list of one or more non-key attribute names that are projected into the secondary index. The total count of attributes provided in NonKeyAttributes, summed across all of the secondary indexes, must not exceed 100. If you project the same attribute into two different indexes, this counts as two distinct attributes when determining the total.    . Defaults to None.
        global_secondary_indexes(List, optional): One or more global secondary indexes (the maximum is 20) to be created on the table. Each global secondary index in the array includes the following:    IndexName - The name of the global secondary index. Must be unique only for this table.     KeySchema - Specifies the key schema for the global secondary index.    Projection - Specifies attributes that are copied (projected) from the table into the index. These are in addition to the primary key attributes and index key attributes, which are automatically projected. Each attribute specification is composed of:    ProjectionType - One of the following:    KEYS_ONLY - Only the index and primary keys are projected into the index.    INCLUDE - Only the specified table attributes are projected into the index. The list of projected attributes is in NonKeyAttributes.    ALL - All of the table attributes are projected into the index.      NonKeyAttributes - A list of one or more non-key attribute names that are projected into the secondary index. The total count of attributes provided in NonKeyAttributes, summed across all of the secondary indexes, must not exceed 100. If you project the same attribute into two different indexes, this counts as two distinct attributes when determining the total.      ProvisionedThroughput - The provisioned throughput settings for the global secondary index, consisting of read and write capacity units.  . Defaults to None.
        billing_mode(str, optional): Controls how you are charged for read and write throughput and how you manage capacity. This setting can be changed later.    PROVISIONED - We recommend using PROVISIONED for predictable workloads. PROVISIONED sets the billing mode to Provisioned Mode.    PAY_PER_REQUEST - We recommend using PAY_PER_REQUEST for unpredictable workloads. PAY_PER_REQUEST sets the billing mode to On-Demand Mode.   . Defaults to None.
        provisioned_throughput(Dict, optional): Represents the provisioned throughput settings for a specified table or index. The settings can be modified using the UpdateTable operation.  If you set BillingMode as PROVISIONED, you must specify this property. If you set BillingMode as PAY_PER_REQUEST, you cannot specify this property. For current minimum and maximum provisioned throughput values, see Service, Account, and Table Quotas in the Amazon DynamoDB Developer Guide. Defaults to None.
        stream_specification(Dict, optional): The settings for DynamoDB Streams on the table. These settings consist of:    StreamEnabled - Indicates whether DynamoDB Streams is to be enabled (true) or disabled (false).    StreamViewType - When an item in the table is modified, StreamViewType determines what information is written to the table's stream. Valid values for StreamViewType are:    KEYS_ONLY - Only the key attributes of the modified item are written to the stream.    NEW_IMAGE - The entire item, as it appears after it was modified, is written to the stream.    OLD_IMAGE - The entire item, as it appeared before it was modified, is written to the stream.    NEW_AND_OLD_IMAGES - Both the new and the old item images of the item are written to the stream.    . Defaults to None.
        sse_specification(Dict, optional): Represents the settings used to enable server-side encryption. Defaults to None.
        tags(List, optional): A list of key-value pairs to label the table. For more information, see Tagging for DynamoDB. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.table.init.create(
                ctx, attribute_definitions=value, table_name=value, key_schema=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.table.init.create attribute_definitions=value, table_name=value, key_schema=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="create_table",
        op_kwargs={
            "AttributeDefinitions": attribute_definitions,
            "TableName": table_name,
            "KeySchema": key_schema,
            "LocalSecondaryIndexes": local_secondary_indexes,
            "GlobalSecondaryIndexes": global_secondary_indexes,
            "BillingMode": billing_mode,
            "ProvisionedThroughput": provisioned_throughput,
            "StreamSpecification": stream_specification,
            "SSESpecification": sse_specification,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, table_name: str) -> Dict:
    r"""
    **Autogenerated function**

    The DeleteTable operation deletes a table and all of its items. After a DeleteTable request, the specified table is in the DELETING state until DynamoDB completes the deletion. If the table is in the ACTIVE state, you can delete it. If a table is in CREATING or UPDATING states, then DynamoDB returns a ResourceInUseException. If the specified table does not exist, DynamoDB returns a ResourceNotFoundException. If table is already in the DELETING state, no error is returned.   DynamoDB might continue to accept data read and write operations, such as GetItem and PutItem, on a table in the DELETING state until the table deletion is complete.  When you delete a table, any indexes on that table are also deleted. If you have DynamoDB Streams enabled on the table, then the corresponding stream on that table goes into the DISABLED state, and the stream is automatically deleted after 24 hours. Use the DescribeTable action to check the status of the table.

    Args:
        table_name(str): The name of the table to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.table.init.delete(ctx, table_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.table.init.delete table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="delete_table",
        op_kwargs={"TableName": table_name},
    )


async def describe(hub, ctx, table_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the table, including the current status of the table, when it was created, the primary key schema, and any indexes on the table.  If you issue a DescribeTable request immediately after a CreateTable request, DynamoDB might return a ResourceNotFoundException. This is because DescribeTable uses an eventually consistent query, and the metadata for your table might not be available at that moment. Wait for a few seconds, and then try the DescribeTable request again.

    Args:
        table_name(str): The name of the table to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.table.init.describe(ctx, table_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.table.init.describe table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="describe_table",
        op_kwargs={"TableName": table_name},
    )


async def list_all(
    hub, ctx, exclusive_start_table_name: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of table names associated with the current account and endpoint. The output from ListTables is paginated, with each page returning a maximum of 100 table names.

    Args:
        exclusive_start_table_name(str, optional): The first table name that this operation will evaluate. Use the value that was returned for LastEvaluatedTableName in a previous operation, so that you can obtain the next page of results. Defaults to None.
        limit(int, optional): A maximum number of table names to return. If this parameter is not specified, the limit is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.table.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.table.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="list_tables",
        op_kwargs={
            "ExclusiveStartTableName": exclusive_start_table_name,
            "Limit": limit,
        },
    )


async def update(
    hub,
    ctx,
    table_name: str,
    attribute_definitions: List = None,
    billing_mode: str = None,
    provisioned_throughput: Dict = None,
    global_secondary_index_updates: List = None,
    stream_specification: Dict = None,
    sse_specification: Dict = None,
    replica_updates: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the provisioned throughput settings, global secondary indexes, or DynamoDB Streams settings for a given table. You can only perform one of the following operations at once:   Modify the provisioned throughput settings of the table.   Enable or disable DynamoDB Streams on the table.   Remove a global secondary index from the table.   Create a new global secondary index on the table. After the index begins backfilling, you can use UpdateTable to perform other operations.    UpdateTable is an asynchronous operation; while it is executing, the table status changes from ACTIVE to UPDATING. While it is UPDATING, you cannot issue another UpdateTable request. When the table returns to the ACTIVE state, the UpdateTable operation is complete.

    Args:
        attribute_definitions(List, optional): An array of attributes that describe the key schema for the table and indexes. If you are adding a new global secondary index to the table, AttributeDefinitions must include the key element(s) of the new index. Defaults to None.
        table_name(str): The name of the table to be updated.
        billing_mode(str, optional): Controls how you are charged for read and write throughput and how you manage capacity. When switching from pay-per-request to provisioned capacity, initial provisioned capacity values must be set. The initial provisioned capacity values are estimated based on the consumed read and write capacity of your table and global secondary indexes over the past 30 minutes.    PROVISIONED - We recommend using PROVISIONED for predictable workloads. PROVISIONED sets the billing mode to Provisioned Mode.    PAY_PER_REQUEST - We recommend using PAY_PER_REQUEST for unpredictable workloads. PAY_PER_REQUEST sets the billing mode to On-Demand Mode.   . Defaults to None.
        provisioned_throughput(Dict, optional): The new provisioned throughput settings for the specified table or index. Defaults to None.
        global_secondary_index_updates(List, optional): An array of one or more global secondary indexes for the table. For each index in the array, you can request one action:    Create - add a new global secondary index to the table.    Update - modify the provisioned throughput settings of an existing global secondary index.    Delete - remove a global secondary index from the table.   You can create or delete only one global secondary index per UpdateTable operation. For more information, see Managing Global Secondary Indexes in the Amazon DynamoDB Developer Guide. . Defaults to None.
        stream_specification(Dict, optional): Represents the DynamoDB Streams configuration for the table.  You receive a ResourceInUseException if you try to enable a stream on a table that already has a stream, or if you try to disable a stream on a table that doesn't have a stream. . Defaults to None.
        sse_specification(Dict, optional): The new server-side encryption settings for the specified table. Defaults to None.
        replica_updates(List, optional): A list of replica update actions (create, delete, or update) for the table.  This property only applies to Version 2019.11.21 of global tables. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.table.init.update(ctx, table_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.table.init.update table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="update_table",
        op_kwargs={
            "AttributeDefinitions": attribute_definitions,
            "TableName": table_name,
            "BillingMode": billing_mode,
            "ProvisionedThroughput": provisioned_throughput,
            "GlobalSecondaryIndexUpdates": global_secondary_index_updates,
            "StreamSpecification": stream_specification,
            "SSESpecification": sse_specification,
            "ReplicaUpdates": replica_updates,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, create_application_request: Dict) -> Dict:
    r"""
    **Autogenerated function**

     Creates an application.

    Args:
        create_application_request(Dict): Specifies the display name of an application and the tags to associate with the application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.app.create(ctx, create_application_request=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.app.create create_application_request=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="create_app",
        op_kwargs={"CreateApplicationRequest": create_application_request},
    )


async def delete(hub, ctx, application_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.app.delete(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.app.delete application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="delete_app",
        op_kwargs={"ApplicationId": application_id},
    )


async def get(hub, ctx, application_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.app.get(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.app.get application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="get_app",
        op_kwargs={"ApplicationId": application_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(
    hub, ctx, application_name: str, current_application_version_id: int, output: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Adds an external destination to your SQL-based Kinesis Data Analytics application. If you want Kinesis Data Analytics to deliver data from an in-application stream within your application to an external destination (such as an Kinesis data stream, a Kinesis Data Firehose delivery stream, or an AWS Lambda function), you add the relevant configuration to your application using this operation. You can configure one or more outputs for your application. Each output configuration maps an in-application stream and an external destination.  You can use one of the output configurations to deliver data from your in-application error stream to an external destination so that you can analyze the errors.   Any configuration update, including adding a streaming source using this operation, results in a new version of the application. You can use the DescribeApplication operation to find the current application version.

    Args:
        application_name(str): The name of the application to which you want to add the output configuration.
        current_application_version_id(int): The version of the application to which you want to add the output configuration. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the ConcurrentModificationException is returned. .
        output(Dict): An array of objects, each describing one output configuration. In the output configuration, you specify the name of an in-application stream, a destination (that is, a Kinesis data stream, a Kinesis Data Firehose delivery stream, or an AWS Lambda function), and record the formation to use when writing to the destination.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.output.add(
                ctx, application_name=value, current_application_version_id=value, output=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.output.add application_name=value, current_application_version_id=value, output=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="add_application_output",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "Output": output,
        },
    )


async def delete(
    hub, ctx, application_name: str, current_application_version_id: int, output_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the output destination configuration from your SQL-based Kinesis Data Analytics application's configuration. Kinesis Data Analytics will no longer write data from the corresponding in-application stream to the external output destination.

    Args:
        application_name(str): The application name.
        current_application_version_id(int): The application version. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the ConcurrentModificationException is returned. .
        output_id(str): The ID of the configuration to delete. Each output configuration that is added to the application (either when the application is created or later) using the AddApplicationOutput operation has a unique ID. You need to provide the ID to uniquely identify the output configuration that you want to delete from the application configuration. You can use the DescribeApplication operation to get the specific OutputId. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.output.delete(
                ctx, application_name=value, current_application_version_id=value, output_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.output.delete application_name=value, current_application_version_id=value, output_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="delete_application_output",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "OutputId": output_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def detect(
    hub, ctx, project_name: str, model_version: str, body: bytes, content_type: str
) -> Dict:
    r"""
    **Autogenerated function**

    Detects anomalies in an image that you supply.  The response from DetectAnomalies includes a boolean prediction that the image contains one or more anomalies and a confidence value for the prediction.  Before calling DetectAnomalies, you must first start your model with the StartModel operation. You are charged for the amount of time, in minutes, that a model runs and for the number of anomaly detection units that your model uses. If you are not using a model, use the StopModel operation to stop your model.   This operation requires permissions to perform the lookoutvision:DetectAnomalies operation.

    Args:
        project_name(str): The name of the project that contains the model version that you want to use.
        model_version(str): The version of the model that you want to use.
        body(bytes): The unencrypted image bytes that you want to analyze. .
        content_type(str): The type of the image passed in Body. Valid values are image/png (PNG format images) and image/jpeg (JPG format images). .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutvision.anomaly.detect(
                ctx, project_name=value, model_version=value, body=value, content_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutvision.anomaly.detect project_name=value, model_version=value, body=value, content_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutvision",
        operation="detect_anomalies",
        op_kwargs={
            "ProjectName": project_name,
            "ModelVersion": model_version,
            "Body": body,
            "ContentType": content_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    client_token: str,
    file_system_id: str,
    tags: List = None,
    posix_user: Dict = None,
    root_directory: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an EFS access point. An access point is an application-specific view into an EFS file system that applies an operating system user and group, and a file system path, to any file system request made through the access point. The operating system user and group override any identity information provided by the NFS client. The file system path is exposed as the access point's root directory. Applications using the access point can only access data in its own directory and below. To learn more, see Mounting a file system using EFS access points. This operation requires permissions for the elasticfilesystem:CreateAccessPoint action.

    Args:
        client_token(str): A string of up to 64 ASCII characters that Amazon EFS uses to ensure idempotent creation.
        tags(List, optional): Creates tags associated with the access point. Each tag is a key-value pair. Defaults to None.
        file_system_id(str): The ID of the EFS file system that the access point provides access to.
        posix_user(Dict, optional): The operating system user and group applied to all file system requests made using the access point. Defaults to None.
        root_directory(Dict, optional): Specifies the directory on the Amazon EFS file system that the access point exposes as the root directory of your file system to NFS clients using the access point. The clients using the access point can only access the root directory and below. If the RootDirectory > Path specified does not exist, EFS creates it and applies the CreationInfo settings when a client connects to an access point. When specifying a RootDirectory, you need to provide the Path, and the CreationInfo. Amazon EFS creates a root directory only if you have provided the CreationInfo: OwnUid, OwnGID, and permissions for the directory. If you do not provide this information, Amazon EFS does not create the root directory. If the root directory does not exist, attempts to mount using the access point will fail. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.access_point.create(
                ctx, client_token=value, file_system_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.access_point.create client_token=value, file_system_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="create_access_point",
        op_kwargs={
            "ClientToken": client_token,
            "Tags": tags,
            "FileSystemId": file_system_id,
            "PosixUser": posix_user,
            "RootDirectory": root_directory,
        },
    )


async def delete(hub, ctx, access_point_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified access point. After deletion is complete, new clients can no longer connect to the access points. Clients connected to the access point at the time of deletion will continue to function until they terminate their connection. This operation requires permissions for the elasticfilesystem:DeleteAccessPoint action.

    Args:
        access_point_id(str): The ID of the access point that you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.access_point.delete(ctx, access_point_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.access_point.delete access_point_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="delete_access_point",
        op_kwargs={"AccessPointId": access_point_id},
    )


async def describe_all(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    access_point_id: str = None,
    file_system_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the description of a specific Amazon EFS access point if the AccessPointId is provided. If you provide an EFS FileSystemId, it returns descriptions of all access points for that file system. You can provide either an AccessPointId or a FileSystemId in the request, but not both.  This operation requires permissions for the elasticfilesystem:DescribeAccessPoints action.

    Args:
        max_results(int, optional): (Optional) When retrieving all access points for a file system, you can optionally specify the MaxItems parameter to limit the number of objects returned in a response. The default value is 100. . Defaults to None.
        next_token(str, optional):  NextToken is present if the response is paginated. You can use NextMarker in the subsequent request to fetch the next page of access point descriptions. Defaults to None.
        access_point_id(str, optional): (Optional) Specifies an EFS access point to describe in the response; mutually exclusive with FileSystemId. Defaults to None.
        file_system_id(str, optional): (Optional) If you provide a FileSystemId, EFS returns all access points for that file system; mutually exclusive with AccessPointId. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.efs.access_point.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.efs.access_point.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="efs",
        operation="describe_access_points",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "AccessPointId": access_point_id,
            "FileSystemId": file_system_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, instance_id: str, dry_run: bool = None, wake_up: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve a JPG-format screenshot of a running instance to help with troubleshooting. The returned content is Base64-encoded.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_id(str): The ID of the instance.
        wake_up(bool, optional): When set to true, acts as keystroke input and wakes up an instance that's in standby or "sleep" mode. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.console.screenshot.get(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.console.screenshot.get instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_console_screenshot",
        op_kwargs={"DryRun": dry_run, "InstanceId": instance_id, "WakeUp": wake_up},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a single Job by ID.

    Args:
        job_id(str): Request to delete Job from service by Job ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.job.init.delete(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.job.init.delete job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="mgn", operation="delete_job", op_kwargs={"jobID": job_id}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    rest_api_id: str,
    name: str,
    type_: str,
    provider_ar_ns: List = None,
    auth_type: str = None,
    authorizer_uri: str = None,
    authorizer_credentials: str = None,
    identity_source: str = None,
    identity_validation_expression: str = None,
    authorizer_result_ttl_in_seconds: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a new Authorizer resource to an existing RestApi resource. AWS CLI

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        name(str): [Required] The name of the authorizer.
        type_(str): [Required] The authorizer type. Valid values are TOKEN for a Lambda function using a single authorization token submitted in a custom header, REQUEST for a Lambda function using incoming request parameters, and COGNITO_USER_POOLS for using an Amazon Cognito user pool.
        provider_ar_ns(List, optional): A list of the Amazon Cognito user pool ARNs for the COGNITO_USER_POOLS authorizer. Each element is of this format: arn:aws:cognito-idp:{region}:{account_id}:userpool/{user_pool_id}. For a TOKEN or REQUEST authorizer, this is not defined. Defaults to None.
        auth_type(str, optional): Optional customer-defined field, used in OpenAPI imports and exports without functional impact. Defaults to None.
        authorizer_uri(str, optional): Specifies the authorizer's Uniform Resource Identifier (URI). For TOKEN or REQUEST authorizers, this must be a well-formed Lambda function URI, for example, arn:aws:apigateway:us-west-2:lambda:path/2015-03-31/functions/arn:aws:lambda:us-west-2:{account_id}:function:{lambda_function_name}/invocations. In general, the URI has this form arn:aws:apigateway:{region}:lambda:path/{service_api}, where {region} is the same as the region hosting the Lambda function, path indicates that the remaining substring in the URI should be treated as the path to the resource, including the initial /. For Lambda functions, this is usually of the form /2015-03-31/functions/[FunctionARN]/invocations. Defaults to None.
        authorizer_credentials(str, optional): Specifies the required credentials as an IAM role for API Gateway to invoke the authorizer. To specify an IAM role for API Gateway to assume, use the role's Amazon Resource Name (ARN). To use resource-based permissions on the Lambda function, specify null. Defaults to None.
        identity_source(str, optional): The identity source for which authorization is requested. For a TOKEN or COGNITO_USER_POOLS authorizer, this is required and specifies the request header mapping expression for the custom header holding the authorization token submitted by the client. For example, if the token header name is Auth, the header mapping expression is method.request.header.Auth.For the REQUEST authorizer, this is required when authorization caching is enabled. The value is a comma-separated string of one or more mapping expressions of the specified request parameters. For example, if an Auth header, a Name query string parameter are defined as identity sources, this value is method.request.header.Auth, method.request.querystring.Name. These parameters will be used to derive the authorization caching key and to perform runtime validation of the REQUEST authorizer by verifying all of the identity-related request parameters are present, not null and non-empty. Only when this is true does the authorizer invoke the authorizer Lambda function, otherwise, it returns a 401 Unauthorized response without calling the Lambda function. The valid value is a string of comma-separated mapping expressions of the specified request parameters. When the authorization caching is not enabled, this property is optional. Defaults to None.
        identity_validation_expression(str, optional): A validation expression for the incoming identity token. For TOKEN authorizers, this value is a regular expression. For COGNITO_USER_POOLS authorizers, API Gateway will match the aud field of the incoming token from the client against the specified regular expression. It will invoke the authorizer's Lambda function when there is a match. Otherwise, it will return a 401 Unauthorized response without calling the Lambda function. The validation expression does not apply to the REQUEST authorizer. Defaults to None.
        authorizer_result_ttl_in_seconds(int, optional): The TTL in seconds of cached authorizer results. If it equals 0, authorization caching is disabled. If it is greater than 0, API Gateway will cache authorizer responses. If this field is not set, the default value is 300. The maximum value is 3600, or 1 hour. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.authorizer.create(
                ctx, rest_api_id=value, name=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.authorizer.create rest_api_id=value, name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="create_authorizer",
        op_kwargs={
            "restApiId": rest_api_id,
            "name": name,
            "type": type_,
            "providerARNs": provider_ar_ns,
            "authType": auth_type,
            "authorizerUri": authorizer_uri,
            "authorizerCredentials": authorizer_credentials,
            "identitySource": identity_source,
            "identityValidationExpression": identity_validation_expression,
            "authorizerResultTtlInSeconds": authorizer_result_ttl_in_seconds,
        },
    )


async def delete(hub, ctx, rest_api_id: str, authorizer_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an existing Authorizer resource. AWS CLI

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        authorizer_id(str): [Required] The identifier of the Authorizer resource.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.authorizer.delete(
                ctx, rest_api_id=value, authorizer_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.authorizer.delete rest_api_id=value, authorizer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_authorizer",
        op_kwargs={"restApiId": rest_api_id, "authorizerId": authorizer_id},
    )


async def get(hub, ctx, rest_api_id: str, authorizer_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describe an existing Authorizer resource. AWS CLI

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        authorizer_id(str): [Required] The identifier of the Authorizer resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.authorizer.get(
                ctx, rest_api_id=value, authorizer_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.authorizer.get rest_api_id=value, authorizer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_authorizer",
        op_kwargs={"restApiId": rest_api_id, "authorizerId": authorizer_id},
    )


async def get_all(
    hub, ctx, rest_api_id: str, position: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describe an existing Authorizers resource. AWS CLI

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.authorizer.get_all(ctx, rest_api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.authorizer.get_all rest_api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_authorizers",
        op_kwargs={"restApiId": rest_api_id, "position": position, "limit": limit},
    )


async def update(
    hub, ctx, rest_api_id: str, authorizer_id: str, patch_operations: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing Authorizer resource. AWS CLI

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        authorizer_id(str): [Required] The identifier of the Authorizer resource.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.authorizer.update(
                ctx, rest_api_id=value, authorizer_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.authorizer.update rest_api_id=value, authorizer_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_authorizer",
        op_kwargs={
            "restApiId": rest_api_id,
            "authorizerId": authorizer_id,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    id_: str,
    authorization: Dict = None,
    egress_access_logs: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new MediaPackage VOD PackagingGroup resource.

    Args:
        authorization(Dict, optional): CDN Authorization credentials. Defaults to None.
        egress_access_logs(Dict, optional): Configure egress access logging. Defaults to None.
        id_(str): The ID of the PackagingGroup.
        tags(Dict, optional): A collection of tags associated with a resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage_vod.packaging.group.create(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage_vod.packaging.group.create id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage-vod",
        operation="create_packaging_group",
        op_kwargs={
            "Authorization": authorization,
            "EgressAccessLogs": egress_access_logs,
            "Id": id_,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a MediaPackage VOD PackagingGroup resource.

    Args:
        id_(str): The ID of the MediaPackage VOD PackagingGroup resource to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage_vod.packaging.group.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage_vod.packaging.group.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage-vod",
        operation="delete_packaging_group",
        op_kwargs={"Id": id_},
    )


async def describe(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a description of a MediaPackage VOD PackagingGroup resource.

    Args:
        id_(str): The ID of a MediaPackage VOD PackagingGroup resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage_vod.packaging.group.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage_vod.packaging.group.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage-vod",
        operation="describe_packaging_group",
        op_kwargs={"Id": id_},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a collection of MediaPackage VOD PackagingGroup resources.

    Args:
        max_results(int, optional): Upper bound on number of records to return. Defaults to None.
        next_token(str, optional): A token used to resume pagination from the end of a previous request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage_vod.packaging.group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage_vod.packaging.group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage-vod",
        operation="list_packaging_groups",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(hub, ctx, id_: str, authorization: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates a specific packaging group. You can't change the id attribute or any other system-generated attributes.

    Args:
        authorization(Dict, optional): CDN Authorization credentials. Defaults to None.
        id_(str): The ID of a MediaPackage VOD PackagingGroup resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediapackage_vod.packaging.group.update(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediapackage_vod.packaging.group.update id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediapackage-vod",
        operation="update_packaging_group",
        op_kwargs={"Authorization": authorization, "Id": id_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    lifetime_in_seconds: int,
    assignment_duration_in_seconds: int,
    reward: str,
    title: str,
    description: str,
    max_assignments: int = None,
    auto_approval_delay_in_seconds: int = None,
    keywords: str = None,
    question: str = None,
    requester_annotation: str = None,
    qualification_requirements: List = None,
    unique_request_token: str = None,
    assignment_review_policy: Dict = None,
    hit_review_policy: Dict = None,
    hit_layout_id: str = None,
    hit_layout_parameters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    The CreateHIT operation creates a new Human Intelligence Task (HIT). The new HIT is made available for Workers to find and accept on the Amazon Mechanical Turk website.   This operation allows you to specify a new HIT by passing in values for the properties of the HIT, such as its title, reward amount and number of assignments. When you pass these values to CreateHIT, a new HIT is created for you, with a new HITTypeID. The HITTypeID can be used to create additional HITs in the future without needing to specify common parameters such as the title, description and reward amount each time.  An alternative way to create HITs is to first generate a HITTypeID using the CreateHITType operation and then call the CreateHITWithHITType operation. This is the recommended best practice for Requesters who are creating large numbers of HITs.  CreateHIT also supports several ways to provide question data: by providing a value for the Question parameter that fully specifies the contents of the HIT, or by providing a HitLayoutId and associated HitLayoutParameters.    If a HIT is created with 10 or more maximum assignments, there is an additional fee. For more information, see Amazon Mechanical Turk Pricing.

    Args:
        max_assignments(int, optional):  The number of times the HIT can be accepted and completed before the HIT becomes unavailable. . Defaults to None.
        auto_approval_delay_in_seconds(int, optional):  The number of seconds after an assignment for the HIT has been submitted, after which the assignment is considered Approved automatically unless the Requester explicitly rejects it. . Defaults to None.
        lifetime_in_seconds(int):  An amount of time, in seconds, after which the HIT is no longer available for users to accept. After the lifetime of the HIT elapses, the HIT no longer appears in HIT searches, even if not all of the assignments for the HIT have been accepted. .
        assignment_duration_in_seconds(int):  The amount of time, in seconds, that a Worker has to complete the HIT after accepting it. If a Worker does not complete the assignment within the specified duration, the assignment is considered abandoned. If the HIT is still active (that is, its lifetime has not elapsed), the assignment becomes available for other users to find and accept. .
        reward(str):  The amount of money the Requester will pay a Worker for successfully completing the HIT. .
        title(str):  The title of the HIT. A title should be short and descriptive about the kind of task the HIT contains. On the Amazon Mechanical Turk web site, the HIT title appears in search results, and everywhere the HIT is mentioned. .
        keywords(str, optional):  One or more words or phrases that describe the HIT, separated by commas. These words are used in searches to find HITs. . Defaults to None.
        description(str):  A general description of the HIT. A description includes detailed information about the kind of task the HIT contains. On the Amazon Mechanical Turk web site, the HIT description appears in the expanded view of search results, and in the HIT and assignment screens. A good description gives the user enough information to evaluate the HIT before accepting it. .
        question(str, optional):  The data the person completing the HIT uses to produce the results.   Constraints: Must be a QuestionForm data structure, an ExternalQuestion data structure, or an HTMLQuestion data structure. The XML question data must not be larger than 64 kilobytes (65,535 bytes) in size, including whitespace.  Either a Question parameter or a HITLayoutId parameter must be provided. Defaults to None.
        requester_annotation(str, optional):  An arbitrary data field. The RequesterAnnotation parameter lets your application attach arbitrary data to the HIT for tracking purposes. For example, this parameter could be an identifier internal to the Requester's application that corresponds with the HIT.   The RequesterAnnotation parameter for a HIT is only visible to the Requester who created the HIT. It is not shown to the Worker, or any other Requester.   The RequesterAnnotation parameter may be different for each HIT you submit. It does not affect how your HITs are grouped. . Defaults to None.
        qualification_requirements(List, optional):  Conditions that a Worker's Qualifications must meet in order to accept the HIT. A HIT can have between zero and ten Qualification requirements. All requirements must be met in order for a Worker to accept the HIT. Additionally, other actions can be restricted using the ActionsGuarded field on each QualificationRequirement structure. . Defaults to None.
        unique_request_token(str, optional):  A unique identifier for this request which allows you to retry the call on error without creating duplicate HITs. This is useful in cases such as network timeouts where it is unclear whether or not the call succeeded on the server. If the HIT already exists in the system from a previous call using the same UniqueRequestToken, subsequent calls will return a AWS.MechanicalTurk.HitAlreadyExists error with a message containing the HITId.    Note: It is your responsibility to ensure uniqueness of the token. The unique token expires after 24 hours. Subsequent calls using the same UniqueRequestToken made after the 24 hour limit could create duplicate HITs.  . Defaults to None.
        assignment_review_policy(Dict, optional):  The Assignment-level Review Policy applies to the assignments under the HIT. You can specify for Mechanical Turk to take various actions based on the policy. . Defaults to None.
        hit_review_policy(Dict, optional):  The HIT-level Review Policy applies to the HIT. You can specify for Mechanical Turk to take various actions based on the policy. . Defaults to None.
        hit_layout_id(str, optional):  The HITLayoutId allows you to use a pre-existing HIT design with placeholder values and create an additional HIT by providing those values as HITLayoutParameters.   Constraints: Either a Question parameter or a HITLayoutId parameter must be provided. . Defaults to None.
        hit_layout_parameters(List, optional):  If the HITLayoutId is provided, any placeholder values must be filled in with values using the HITLayoutParameter structure. For more information, see HITLayout. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.hit.init.create(
                ctx,
                lifetime_in_seconds=value,
                assignment_duration_in_seconds=value,
                reward=value,
                title=value,
                description=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.hit.init.create lifetime_in_seconds=value, assignment_duration_in_seconds=value, reward=value, title=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="create_hit",
        op_kwargs={
            "MaxAssignments": max_assignments,
            "AutoApprovalDelayInSeconds": auto_approval_delay_in_seconds,
            "LifetimeInSeconds": lifetime_in_seconds,
            "AssignmentDurationInSeconds": assignment_duration_in_seconds,
            "Reward": reward,
            "Title": title,
            "Keywords": keywords,
            "Description": description,
            "Question": question,
            "RequesterAnnotation": requester_annotation,
            "QualificationRequirements": qualification_requirements,
            "UniqueRequestToken": unique_request_token,
            "AssignmentReviewPolicy": assignment_review_policy,
            "HITReviewPolicy": hit_review_policy,
            "HITLayoutId": hit_layout_id,
            "HITLayoutParameters": hit_layout_parameters,
        },
    )


async def delete(hub, ctx, hit_id: str) -> Dict:
    r"""
    **Autogenerated function**

     The DeleteHIT operation is used to delete HIT that is no longer needed. Only the Requester who created the HIT can delete it.   You can only dispose of HITs that are in the Reviewable state, with all of their submitted assignments already either approved or rejected. If you call the DeleteHIT operation on a HIT that is not in the Reviewable state (for example, that has not expired, or still has active assignments), or on a HIT that is Reviewable but without all of its submitted assignments already approved or rejected, the service will return an error.      HITs are automatically disposed of after 120 days.     After you dispose of a HIT, you can no longer approve the HIT's rejected assignments.     Disposed HITs are not returned in results for the ListHITs operation.     Disposing HITs can improve the performance of operations such as ListReviewableHITs and ListHITs.

    Args:
        hit_id(str): The ID of the HIT to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.hit.init.delete(ctx, hit_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.hit.init.delete hit_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="mturk", operation="delete_hit", op_kwargs={"HITId": hit_id}
    )


async def get(hub, ctx, hit_id: str) -> Dict:
    r"""
    **Autogenerated function**

     The GetHIT operation retrieves the details of the specified HIT.

    Args:
        hit_id(str): The ID of the HIT to be retrieved.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.hit.init.get(ctx, hit_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.hit.init.get hit_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="mturk", operation="get_hit", op_kwargs={"HITId": hit_id}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    role: str,
    server_id: str,
    user_name: str,
    home_directory: str = None,
    home_directory_type: str = None,
    home_directory_mappings: List = None,
    policy: str = None,
    posix_profile: Dict = None,
    ssh_public_key_body: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a user and associates them with an existing file transfer protocol-enabled server. You can only create and associate users with servers that have the IdentityProviderType set to SERVICE_MANAGED. Using parameters for CreateUser, you can specify the user name, set the home directory, store the user's public key, and assign the user's Amazon Web Services Identity and Access Management (IAM) role. You can also optionally add a scope-down policy, and assign metadata with tags that can be used to group and search for users.

    Args:
        home_directory(str, optional): The landing directory (folder) for a user when they log in to the server using the client. A HomeDirectory example is /bucket_name/home/mydirectory. Defaults to None.
        home_directory_type(str, optional): The type of landing directory (folder) you want your users' home directory to be when they log into the server. If you set it to PATH, the user will see the absolute Amazon S3 bucket or EFS paths as is in their file transfer protocol clients. If you set it LOGICAL, you will need to provide mappings in the HomeDirectoryMappings for how you want to make Amazon S3 or EFS paths visible to your users. Defaults to None.
        home_directory_mappings(List, optional): Logical directory mappings that specify what Amazon S3 or Amazon EFS paths and keys should be visible to your user and how you want to make them visible. You must specify the Entry and Target pair, where Entry shows how the path is made visible and Target is the actual Amazon S3 or Amazon EFS path. If you only specify a target, it is displayed as is. You also must ensure that your Amazon Web Services Identity and Access Management (IAM) role provides access to paths in Target. This value can only be set when HomeDirectoryType is set to LOGICAL. The following is an Entry and Target pair example.  [ { "Entry": "your-personal-report.pdf", "Target": "/bucket3/customized-reports/${transfer:UserName}.pdf" } ]  In most cases, you can use this value instead of the scope-down policy to lock your user down to the designated home directory ("chroot"). To do this, you can set Entry to / and set Target to the HomeDirectory parameter value. The following is an Entry and Target pair example for chroot.  [ { "Entry:": "/", "Target": "/bucket_name/home/mydirectory" } ]   If the target of a logical directory entry does not exist in Amazon S3 or EFS, the entry is ignored. As a workaround, you can use the Amazon S3 API or EFS API to create 0 byte objects as place holders for your directory. If using the CLI, use the s3api or efsapi call instead of s3 or efs so you can use the put-object operation. For example, you use the following: aws s3api put-object --bucket bucketname --key path/to/folder/. Make sure that the end of the key name ends in a / for it to be considered a folder. . Defaults to None.
        policy(str, optional): A scope-down policy for your user so that you can use the same IAM role across multiple users. This policy scopes down user access to portions of their Amazon S3 bucket. Variables that you can use inside this policy include ${Transfer:UserName}, ${Transfer:HomeDirectory}, and ${Transfer:HomeBucket}.  This only applies when domain of ServerId is S3. EFS does not use scope down policy. For scope-down policies, Amazon Web Services Transfer Family stores the policy as a JSON blob, instead of the Amazon Resource Name (ARN) of the policy. You save the policy as a JSON blob and pass it in the Policy argument. For an example of a scope-down policy, see Example scope-down policy. For more information, see AssumeRole in the Amazon Web Services Security Token Service API Reference. . Defaults to None.
        posix_profile(Dict, optional): Specifies the full POSIX identity, including user ID (Uid), group ID (Gid), and any secondary groups IDs (SecondaryGids), that controls your users' access to your Amazon EFS file systems. The POSIX permissions that are set on files and directories in Amazon EFS determine the level of access your users get when transferring files into and out of your Amazon EFS file systems. Defaults to None.
        role(str): Specifies the Amazon Resource Name (ARN) of the IAM role that controls your users' access to your Amazon S3 bucket or EFS file system. The policies attached to this role determine the level of access that you want to provide your users when transferring files into and out of your Amazon S3 bucket or EFS file system. The IAM role should also contain a trust relationship that allows the server to access your resources when servicing your users' transfer requests.
        server_id(str): A system-assigned unique identifier for a server instance. This is the specific server that you added your user to.
        ssh_public_key_body(str, optional): The public portion of the Secure Shell (SSH) key used to authenticate the user to the server. Defaults to None.
        tags(List, optional): Key-value pairs that can be used to group and search for users. Tags are metadata attached to users for any purpose. Defaults to None.
        user_name(str): A unique string that identifies a user and is associated with a as specified by the ServerId. This user name must be a minimum of 3 and a maximum of 100 characters long. The following are valid characters: a-z, A-Z, 0-9, underscore '_', hyphen '-', period '.', and at sign '@'. The user name can't start with a hyphen, period, or at sign.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.user.create(
                ctx, role=value, server_id=value, user_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.user.create role=value, server_id=value, user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="create_user",
        op_kwargs={
            "HomeDirectory": home_directory,
            "HomeDirectoryType": home_directory_type,
            "HomeDirectoryMappings": home_directory_mappings,
            "Policy": policy,
            "PosixProfile": posix_profile,
            "Role": role,
            "ServerId": server_id,
            "SshPublicKeyBody": ssh_public_key_body,
            "Tags": tags,
            "UserName": user_name,
        },
    )


async def delete(hub, ctx, server_id: str, user_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the user belonging to a file transfer protocol-enabled server you specify. No response returns from this operation.  When you delete a user from a server, the user's information is lost.

    Args:
        server_id(str): A system-assigned unique identifier for a server instance that has the user assigned to it.
        user_name(str): A unique string that identifies a user that is being deleted from a server.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.user.delete(ctx, server_id=value, user_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.user.delete server_id=value, user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="delete_user",
        op_kwargs={"ServerId": server_id, "UserName": user_name},
    )


async def describe(hub, ctx, server_id: str, user_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the user assigned to the specific file transfer protocol-enabled server, as identified by its ServerId property. The response from this call returns the properties of the user associated with the ServerId value that was specified.

    Args:
        server_id(str): A system-assigned unique identifier for a server that has this user assigned.
        user_name(str): The name of the user assigned to one or more servers. User names are part of the sign-in credentials to use the Amazon Web Services Transfer Family service and perform file transfer tasks.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.user.describe(ctx, server_id=value, user_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.user.describe server_id=value, user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="describe_user",
        op_kwargs={"ServerId": server_id, "UserName": user_name},
    )


async def list_all(
    hub, ctx, server_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the users for a file transfer protocol-enabled server that you specify by passing the ServerId parameter.

    Args:
        max_results(int, optional): Specifies the number of users to return as a response to the ListUsers request. Defaults to None.
        next_token(str, optional): When you can get additional results from the ListUsers call, a NextToken parameter is returned in the output. You can then pass in a subsequent command to the NextToken parameter to continue listing additional users. Defaults to None.
        server_id(str): A system-assigned unique identifier for a server that has users assigned to it.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.user.list_all(ctx, server_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.user.list_all server_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="list_users",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "ServerId": server_id,
        },
    )


async def update(
    hub,
    ctx,
    server_id: str,
    user_name: str,
    home_directory: str = None,
    home_directory_type: str = None,
    home_directory_mappings: List = None,
    policy: str = None,
    posix_profile: Dict = None,
    role: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Assigns new properties to a user. Parameters you pass modify any or all of the following: the home directory, role, and policy for the UserName and ServerId you specify. The response returns the ServerId and the UserName for the updated user.

    Args:
        home_directory(str, optional): The landing directory (folder) for a user when they log in to the server using the client. A HomeDirectory example is /bucket_name/home/mydirectory. Defaults to None.
        home_directory_type(str, optional): The type of landing directory (folder) you want your users' home directory to be when they log into the server. If you set it to PATH, the user will see the absolute Amazon S3 bucket or EFS paths as is in their file transfer protocol clients. If you set it LOGICAL, you will need to provide mappings in the HomeDirectoryMappings for how you want to make Amazon S3 or EFS paths visible to your users. Defaults to None.
        home_directory_mappings(List, optional): Logical directory mappings that specify what Amazon S3 or Amazon EFS paths and keys should be visible to your user and how you want to make them visible. You must specify the Entry and Target pair, where Entry shows how the path is made visible and Target is the actual Amazon S3 or Amazon EFS path. If you only specify a target, it is displayed as is. You also must ensure that your Amazon Web Services Identity and Access Management (IAM) role provides access to paths in Target. This value can only be set when HomeDirectoryType is set to LOGICAL. The following is an Entry and Target pair example.  [ { "Entry": "your-personal-report.pdf", "Target": "/bucket3/customized-reports/${transfer:UserName}.pdf" } ]  In most cases, you can use this value instead of the scope-down policy to lock down your user to the designated home directory ("chroot"). To do this, you can set Entry to '/' and set Target to the HomeDirectory parameter value. The following is an Entry and Target pair example for chroot.  [ { "Entry:": "/", "Target": "/bucket_name/home/mydirectory" } ]   If the target of a logical directory entry does not exist in Amazon S3 or EFS, the entry is ignored. As a workaround, you can use the Amazon S3 API or EFS API to create 0 byte objects as place holders for your directory. If using the CLI, use the s3api or efsapi call instead of s3 or efs so you can use the put-object operation. For example, you use the following: aws s3api put-object --bucket bucketname --key path/to/folder/. Make sure that the end of the key name ends in a / for it to be considered a folder. . Defaults to None.
        policy(str, optional): A scope-down policy for your user so that you can use the same IAM role across multiple users. This policy scopes down user access to portions of their Amazon S3 bucket. Variables that you can use inside this policy include ${Transfer:UserName}, ${Transfer:HomeDirectory}, and ${Transfer:HomeBucket}.  This only applies when domain of ServerId is S3. Amazon EFS does not use scope-down policies. For scope-down policies, Amazon Web ServicesTransfer Family stores the policy as a JSON blob, instead of the Amazon Resource Name (ARN) of the policy. You save the policy as a JSON blob and pass it in the Policy argument. For an example of a scope-down policy, see Creating a scope-down policy. For more information, see AssumeRole in the Amazon Web Services Security Token Service API Reference. . Defaults to None.
        posix_profile(Dict, optional): Specifies the full POSIX identity, including user ID (Uid), group ID (Gid), and any secondary groups IDs (SecondaryGids), that controls your users' access to your Amazon Elastic File Systems (Amazon EFS). The POSIX permissions that are set on files and directories in your file system determines the level of access your users get when transferring files into and out of your Amazon EFS file systems. Defaults to None.
        role(str, optional): Specifies the Amazon Resource Name (ARN) of the IAM role that controls your users' access to your Amazon S3 bucket or EFS file system. The policies attached to this role determine the level of access that you want to provide your users when transferring files into and out of your Amazon S3 bucket or EFS file system. The IAM role should also contain a trust relationship that allows the server to access your resources when servicing your users' transfer requests. Defaults to None.
        server_id(str): A system-assigned unique identifier for a server instance that the user account is assigned to.
        user_name(str): A unique string that identifies a user and is associated with a server as specified by the ServerId. This user name must be a minimum of 3 and a maximum of 100 characters long. The following are valid characters: a-z, A-Z, 0-9, underscore '_', hyphen '-', period '.', and at sign '@'. The user name can't start with a hyphen, period, or at sign.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.user.update(ctx, server_id=value, user_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.user.update server_id=value, user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="update_user",
        op_kwargs={
            "HomeDirectory": home_directory,
            "HomeDirectoryType": home_directory_type,
            "HomeDirectoryMappings": home_directory_mappings,
            "Policy": policy,
            "PosixProfile": posix_profile,
            "Role": role,
            "ServerId": server_id,
            "UserName": user_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    pull_request_id: str,
    pull_request_event_type: str = None,
    actor_arn: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about one or more pull request events.

    Args:
        pull_request_id(str): The system-generated ID of the pull request. To get this ID, use ListPullRequests.
        pull_request_event_type(str, optional): Optional. The pull request event type about which you want to return information. Defaults to None.
        actor_arn(str, optional): The Amazon Resource Name (ARN) of the user whose actions resulted in the event. Examples include updating the pull request with more commits or changing the status of a pull request. Defaults to None.
        next_token(str, optional): An enumeration token that, when provided in a request, returns the next batch of the results. Defaults to None.
        max_results(int, optional): A non-zero, non-negative integer used to limit the number of returned results. The default is 100 events, which is also the maximum number of events that can be returned in a result. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.pull_request.event.describe_all(
                ctx, pull_request_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.pull_request.event.describe_all pull_request_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="describe_pull_request_events",
        op_kwargs={
            "pullRequestId": pull_request_id,
            "pullRequestEventType": pull_request_event_type,
            "actorArn": actor_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def accept(
    hub,
    ctx,
    invitation_id: str,
    administrator_account_id: str = None,
    master_account: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Accepts an Amazon Macie membership invitation that was received from a specific account.

    Args:
        administrator_account_id(str, optional): The Amazon Web Services account ID for the account that sent the invitation. Defaults to None.
        invitation_id(str): The unique identifier for the invitation to accept.
        master_account(str, optional): (Deprecated) The Amazon Web Services account ID for the account that sent the invitation. This property has been replaced by the administratorAccountId property and is retained only for backward compatibility. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.invitation.init.accept(ctx, invitation_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.invitation.init.accept invitation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="accept_invitation",
        op_kwargs={
            "administratorAccountId": administrator_account_id,
            "invitationId": invitation_id,
            "masterAccount": master_account,
        },
    )


async def create_multiple(
    hub,
    ctx,
    account_ids: List,
    disable_email_notification: bool = None,
    message: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sends an Amazon Macie membership invitation to one or more accounts.

    Args:
        account_ids(List): An array that lists Amazon Web Services account IDs, one for each account to send the invitation to.
        disable_email_notification(bool, optional): Specifies whether to send an email notification to the root user of each account that the invitation will be sent to. This notification is in addition to an alert that the root user receives in Personal Health Dashboard. To send an email notification to the root user of each account, set this value to true. Defaults to None.
        message(str, optional): A custom message to include in the invitation. Amazon Macie adds this message to the standard content that it sends for an invitation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.invitation.init.create_multiple(ctx, account_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.invitation.init.create_multiple account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="create_invitations",
        op_kwargs={
            "accountIds": account_ids,
            "disableEmailNotification": disable_email_notification,
            "message": message,
        },
    )


async def decline(hub, ctx, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Declines Amazon Macie membership invitations that were received from specific accounts.

    Args:
        account_ids(List): An array that lists Amazon Web Services account IDs, one for each account that sent an invitation to decline.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.invitation.init.decline(ctx, account_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.invitation.init.decline account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="decline_invitations",
        op_kwargs={"accountIds": account_ids},
    )


async def delete_multiple(hub, ctx, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes Amazon Macie membership invitations that were received from specific accounts.

    Args:
        account_ids(List): An array that lists Amazon Web Services account IDs, one for each account that sent an invitation to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.invitation.init.delete_multiple(ctx, account_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.invitation.init.delete_multiple account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="delete_invitations",
        op_kwargs={"accountIds": account_ids},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about all the Amazon Macie membership invitations that were received by an account.

    Args:
        max_results(int, optional): The maximum number of items to include in each page of a paginated response. Defaults to None.
        next_token(str, optional): The nextToken string that specifies which page of results to return in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie2.invitation.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie2.invitation.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie2",
        operation="list_invitations",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, collection_name: str, geofence_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a batch of geofences from a geofence collection.  This operation deletes the resource permanently.

    Args:
        collection_name(str): The geofence collection storing the geofences to be deleted.
        geofence_ids(List): The batch of geofences to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.delete.geofence.batch(
                ctx, collection_name=value, geofence_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.delete.geofence.batch collection_name=value, geofence_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="batch_delete_geofence",
        op_kwargs={"CollectionName": collection_name, "GeofenceIds": geofence_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    fleet_id: str = None,
    game_session_id: str = None,
    alias_id: str = None,
    location: str = None,
    status_filter: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves additional game session properties, including the game session protection policy in force, a set of one or more game sessions in a specific fleet location. You can optionally filter the results by current game session status. Alternatively, use SearchGameSessions to request a set of active game sessions that are filtered by certain criteria. To retrieve all game session properties, use DescribeGameSessions.  This operation can be used in the following ways:    To retrieve details for all game sessions that are currently running on all locations in a fleet, provide a fleet or alias ID, with an optional status filter. This approach returns details from the fleet's home Region and all remote locations.   To retrieve details for all game sessions that are currently running on a specific fleet location, provide a fleet or alias ID and a location name, with optional status filter. The location can be the fleet's home Region or any remote location.   To retrieve details for a specific game session, provide the game session ID. This approach looks for the game session ID in all fleets that reside in the AWS Region defined in the request.   Use the pagination parameters to retrieve results as a set of sequential pages.  If successful, a GameSessionDetail object is returned for each game session that matches the request.  Learn more   Find a game session   Related actions   CreateGameSession | DescribeGameSessions | DescribeGameSessionDetails | SearchGameSessions | UpdateGameSession | GetGameSessionLogUrl | StartGameSessionPlacement | DescribeGameSessionPlacement | StopGameSessionPlacement | All APIs by task

    Args:
        fleet_id(str, optional): A unique identifier for the fleet to retrieve all game sessions active on the fleet. You can use either the fleet ID or ARN value. Defaults to None.
        game_session_id(str, optional): A unique identifier for the game session to retrieve. . Defaults to None.
        alias_id(str, optional): A unique identifier for the alias associated with the fleet to retrieve all game sessions for. You can use either the alias ID or ARN value. Defaults to None.
        location(str, optional): A fleet location to get game sessions for. You can specify a fleet's home Region or a remote location. Use the AWS Region code format, such as us-west-2. . Defaults to None.
        status_filter(str, optional): Game session status to filter results on. Possible game session statuses include ACTIVE, TERMINATED, ACTIVATING and TERMINATING (the last two are transitory). . Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.session.detail.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.session.detail.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_game_session_details",
        op_kwargs={
            "FleetId": fleet_id,
            "GameSessionId": game_session_id,
            "AliasId": alias_id,
            "Location": location,
            "StatusFilter": status_filter,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, platform_application_arn: str, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the endpoints and endpoint attributes for devices in a supported push notification service, such as GCM (Firebase Cloud Messaging) and APNS. The results for ListEndpointsByPlatformApplication are paginated and return a limited list of endpoints, up to 100. If additional records are available after the first page results, then a NextToken string will be returned. To receive the next page, you call ListEndpointsByPlatformApplication again using the NextToken string received from the previous call. When there are no more records to return, NextToken will be null. For more information, see Using Amazon SNS Mobile Push Notifications.  This action is throttled at 30 transactions per second (TPS).

    Args:
        platform_application_arn(str): PlatformApplicationArn for ListEndpointsByPlatformApplicationInput action.
        next_token(str, optional): NextToken string is used when calling ListEndpointsByPlatformApplication action to retrieve additional records that are available after the first page results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.endpoint.by_platform_application.list(
                ctx, platform_application_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.endpoint.by_platform_application.list platform_application_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="list_endpoints_by_platform_application",
        op_kwargs={
            "PlatformApplicationArn": platform_application_arn,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, function_name: str, qualifier: str = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the configuration for asynchronous invocation for a function, version, or alias. To configure options for asynchronous invocation, use PutFunctionEventInvokeConfig.

    Args:
        function_name(str): The name of the Lambda function, version, or alias.  Name formats     Function name - my-function (name-only), my-function:v1 (with alias).    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        qualifier(str, optional): A version number or alias name. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.event_invoke_config.delete(
                ctx, function_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.event_invoke_config.delete function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="delete_function_event_invoke_config",
        op_kwargs={"FunctionName": function_name, "Qualifier": qualifier},
    )


async def get(hub, ctx, function_name: str, qualifier: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the configuration for asynchronous invocation for a function, version, or alias. To configure options for asynchronous invocation, use PutFunctionEventInvokeConfig.

    Args:
        function_name(str): The name of the Lambda function, version, or alias.  Name formats     Function name - my-function (name-only), my-function:v1 (with alias).    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        qualifier(str, optional): A version number or alias name. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.event_invoke_config.get(
                ctx, function_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.event_invoke_config.get function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="get_function_event_invoke_config",
        op_kwargs={"FunctionName": function_name, "Qualifier": qualifier},
    )


async def list_all(
    hub, ctx, function_name: str, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of configurations for asynchronous invocation for a function. To configure options for asynchronous invocation, use PutFunctionEventInvokeConfig.

    Args:
        function_name(str): The name of the Lambda function.  Name formats     Function name - my-function.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        marker(str, optional): Specify the pagination token that's returned by a previous request to retrieve the next page of results. Defaults to None.
        max_items(int, optional): The maximum number of configurations to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.event_invoke_config.list_all(
                ctx, function_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.event_invoke_config.list_all function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="list_function_event_invoke_configs",
        op_kwargs={
            "FunctionName": function_name,
            "Marker": marker,
            "MaxItems": max_items,
        },
    )


async def put(
    hub,
    ctx,
    function_name: str,
    qualifier: str = None,
    maximum_retry_attempts: int = None,
    maximum_event_age_in_seconds: int = None,
    destination_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Configures options for asynchronous invocation on a function, version, or alias. If a configuration already exists for a function, version, or alias, this operation overwrites it. If you exclude any settings, they are removed. To set one option without affecting existing settings for other options, use UpdateFunctionEventInvokeConfig. By default, Lambda retries an asynchronous invocation twice if the function returns an error. It retains events in a queue for up to six hours. When an event fails all processing attempts or stays in the asynchronous invocation queue for too long, Lambda discards it. To retain discarded events, configure a dead-letter queue with UpdateFunctionConfiguration. To send an invocation record to a queue, topic, function, or event bus, specify a destination. You can configure separate destinations for successful invocations (on-success) and events that fail all processing attempts (on-failure). You can configure destinations in addition to or instead of a dead-letter queue.

    Args:
        function_name(str): The name of the Lambda function, version, or alias.  Name formats     Function name - my-function (name-only), my-function:v1 (with alias).    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        qualifier(str, optional): A version number or alias name. Defaults to None.
        maximum_retry_attempts(int, optional): The maximum number of times to retry when the function returns an error. Defaults to None.
        maximum_event_age_in_seconds(int, optional): The maximum age of a request that Lambda sends to a function for processing. Defaults to None.
        destination_config(Dict, optional): A destination for events after they have been sent to a function for processing.  Destinations     Function - The Amazon Resource Name (ARN) of a Lambda function.    Queue - The ARN of an SQS queue.    Topic - The ARN of an SNS topic.    Event Bus - The ARN of an Amazon EventBridge event bus.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.event_invoke_config.put(
                ctx, function_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.event_invoke_config.put function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="put_function_event_invoke_config",
        op_kwargs={
            "FunctionName": function_name,
            "Qualifier": qualifier,
            "MaximumRetryAttempts": maximum_retry_attempts,
            "MaximumEventAgeInSeconds": maximum_event_age_in_seconds,
            "DestinationConfig": destination_config,
        },
    )


async def update(
    hub,
    ctx,
    function_name: str,
    qualifier: str = None,
    maximum_retry_attempts: int = None,
    maximum_event_age_in_seconds: int = None,
    destination_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the configuration for asynchronous invocation for a function, version, or alias. To configure options for asynchronous invocation, use PutFunctionEventInvokeConfig.

    Args:
        function_name(str): The name of the Lambda function, version, or alias.  Name formats     Function name - my-function (name-only), my-function:v1 (with alias).    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.    Partial ARN - 123456789012:function:my-function.   You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        qualifier(str, optional): A version number or alias name. Defaults to None.
        maximum_retry_attempts(int, optional): The maximum number of times to retry when the function returns an error. Defaults to None.
        maximum_event_age_in_seconds(int, optional): The maximum age of a request that Lambda sends to a function for processing. Defaults to None.
        destination_config(Dict, optional): A destination for events after they have been sent to a function for processing.  Destinations     Function - The Amazon Resource Name (ARN) of a Lambda function.    Queue - The ARN of an SQS queue.    Topic - The ARN of an SNS topic.    Event Bus - The ARN of an Amazon EventBridge event bus.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.function.event_invoke_config.update(
                ctx, function_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.function.event_invoke_config.update function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="update_function_event_invoke_config",
        op_kwargs={
            "FunctionName": function_name,
            "Qualifier": qualifier,
            "MaximumRetryAttempts": maximum_retry_attempts,
            "MaximumEventAgeInSeconds": maximum_event_age_in_seconds,
            "DestinationConfig": destination_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, repository_name: str, branch_name: str, commit_id: str
) -> None:
    r"""
    **Autogenerated function**

    Creates a branch in a repository and points the branch to a commit.  Calling the create branch operation does not set a repository's default branch. To do this, call the update default branch operation.

    Args:
        repository_name(str): The name of the repository in which you want to create the new branch.
        branch_name(str): The name of the new branch to create.
        commit_id(str): The ID of the commit to point the new branch to.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.branch.init.create(
                ctx, repository_name=value, branch_name=value, commit_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.branch.init.create repository_name=value, branch_name=value, commit_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="create_branch",
        op_kwargs={
            "repositoryName": repository_name,
            "branchName": branch_name,
            "commitId": commit_id,
        },
    )


async def delete(hub, ctx, repository_name: str, branch_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a branch from a repository, unless that branch is the default branch for the repository.

    Args:
        repository_name(str): The name of the repository that contains the branch to be deleted.
        branch_name(str): The name of the branch to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.branch.init.delete(
                ctx, repository_name=value, branch_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.branch.init.delete repository_name=value, branch_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="delete_branch",
        op_kwargs={"repositoryName": repository_name, "branchName": branch_name},
    )


async def get(hub, ctx, repository_name: str = None, branch_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a repository branch, including its name and the last commit ID.

    Args:
        repository_name(str, optional): The name of the repository that contains the branch for which you want to retrieve information. Defaults to None.
        branch_name(str, optional): The name of the branch for which you want to retrieve information. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.branch.init.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.branch.init.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="get_branch",
        op_kwargs={"repositoryName": repository_name, "branchName": branch_name},
    )


async def list_all(hub, ctx, repository_name: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about one or more branches in a repository.

    Args:
        repository_name(str): The name of the repository that contains the branches.
        next_token(str, optional): An enumeration token that allows the operation to batch the results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.branch.init.list_all(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.branch.init.list_all repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="list_branches",
        op_kwargs={"repositoryName": repository_name, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, pipeline_name: str, pipeline_activities: List, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a pipeline. A pipeline consumes messages from a channel and allows you to process the messages before storing them in a data store. You must specify both a channel and a datastore activity and, optionally, as many as 23 additional activities in the pipelineActivities array.

    Args:
        pipeline_name(str): The name of the pipeline.
        pipeline_activities(List): A list of PipelineActivity objects. Activities perform transformations on your messages, such as removing, renaming or adding message attributes; filtering messages based on attribute values; invoking your Lambda unctions on messages for advanced processing; or performing mathematical transformations to normalize device data. The list can be 2-25 PipelineActivity objects and must contain both a channel and a datastore activity. Each entry in the list must contain only one activity. For example:  pipelineActivities = [ { "channel": { ... } }, { "lambda": { ... } }, ... ] .
        tags(List, optional): Metadata which can be used to manage the pipeline. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.pipeline.init.create(
                ctx, pipeline_name=value, pipeline_activities=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.pipeline.init.create pipeline_name=value, pipeline_activities=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="create_pipeline",
        op_kwargs={
            "pipelineName": pipeline_name,
            "pipelineActivities": pipeline_activities,
            "tags": tags,
        },
    )


async def delete(hub, ctx, pipeline_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified pipeline.

    Args:
        pipeline_name(str): The name of the pipeline to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.pipeline.init.delete(ctx, pipeline_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.pipeline.init.delete pipeline_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="delete_pipeline",
        op_kwargs={"pipelineName": pipeline_name},
    )


async def describe(hub, ctx, pipeline_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a pipeline.

    Args:
        pipeline_name(str): The name of the pipeline whose information is retrieved.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.pipeline.init.describe(ctx, pipeline_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.pipeline.init.describe pipeline_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="describe_pipeline",
        op_kwargs={"pipelineName": pipeline_name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of pipelines.

    Args:
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this request. The default value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.pipeline.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.pipeline.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="list_pipelines",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(hub, ctx, pipeline_name: str, pipeline_activities: List) -> None:
    r"""
    **Autogenerated function**

    Updates the settings of a pipeline. You must specify both a channel and a datastore activity and, optionally, as many as 23 additional activities in the pipelineActivities array.

    Args:
        pipeline_name(str): The name of the pipeline to update.
        pipeline_activities(List): A list of PipelineActivity objects. Activities perform transformations on your messages, such as removing, renaming or adding message attributes; filtering messages based on attribute values; invoking your Lambda functions on messages for advanced processing; or performing mathematical transformations to normalize device data. The list can be 2-25 PipelineActivity objects and must contain both a channel and a datastore activity. Each entry in the list must contain only one activity. For example:  pipelineActivities = [ { "channel": { ... } }, { "lambda": { ... } }, ... ] .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.pipeline.init.update(
                ctx, pipeline_name=value, pipeline_activities=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.pipeline.init.update pipeline_name=value, pipeline_activities=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="update_pipeline",
        op_kwargs={
            "pipelineName": pipeline_name,
            "pipelineActivities": pipeline_activities,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, resource_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the tags associated with an Athena workgroup or data catalog resource.

    Args:
        resource_arn(str): Lists the tags for the resource with the specified ARN.
        next_token(str, optional): The token for the next set of results, or null if there are no additional results for this request, where the request lists the tags for the resource with the specified ARN. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request that lists the tags for the resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.athena.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.athena.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="athena",
        operation="list_tags_for_resource",
        op_kwargs={
            "ResourceARN": resource_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    game_server_group_name: str,
    instance_ids: List = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     This operation is used with the GameLift FleetIQ solution and game server groups.  Retrieves status information about the Amazon EC2 instances associated with a GameLift FleetIQ game server group. Use this operation to detect when instances are active or not available to host new game servers. If you are looking for instance configuration information, call DescribeGameServerGroup or access the corresponding Auto Scaling group properties. To request status for all instances in the game server group, provide a game server group ID only. To request status for specific instances, provide the game server group ID and one or more instance IDs. Use the pagination parameters to retrieve results in sequential segments. If successful, a collection of GameServerInstance objects is returned.  This operation is not designed to be called with every game server claim request; this practice can cause you to exceed your API limit, which results in errors. Instead, as a best practice, cache the results and refresh your cache no more than once every 10 seconds.  Learn more   GameLift FleetIQ Guide   Related actions   CreateGameServerGroup | ListGameServerGroups | DescribeGameServerGroup | UpdateGameServerGroup | DeleteGameServerGroup | ResumeGameServerGroup | SuspendGameServerGroup | DescribeGameServerInstances | All APIs by task

    Args:
        game_server_group_name(str): A unique identifier for the game server group. Use either the GameServerGroup name or ARN value.
        instance_ids(List, optional): The EC2 instance IDs that you want to retrieve status on. EC2 instance IDs use a 17-character format, for example: i-1234567890abcdef0. To retrieve all instances in the game server group, leave this parameter empty. . Defaults to None.
        limit(int, optional):  The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. . Defaults to None.
        next_token(str, optional):  A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.server.instance.describe_all(
                ctx, game_server_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.server.instance.describe_all game_server_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_game_server_instances",
        op_kwargs={
            "GameServerGroupName": game_server_group_name,
            "InstanceIds": instance_ids,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def retry(
    hub,
    ctx,
    pipeline_name: str,
    stage_name: str,
    pipeline_execution_id: str,
    retry_mode: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Resumes the pipeline execution by retrying the last failed actions in a stage. You can retry a stage immediately if any of the actions in the stage fail. When you retry, all actions that are still in progress continue working, and failed actions are triggered again.

    Args:
        pipeline_name(str): The name of the pipeline that contains the failed stage.
        stage_name(str): The name of the failed stage to be retried.
        pipeline_execution_id(str): The ID of the pipeline execution in the failed stage to be retried. Use the GetPipelineState action to retrieve the current pipelineExecutionId of the failed stage.
        retry_mode(str): The scope of the retry attempt. Currently, the only supported value is FAILED_ACTIONS.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.stage.execution.retry(
                ctx,
                pipeline_name=value,
                stage_name=value,
                pipeline_execution_id=value,
                retry_mode=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.stage.execution.retry pipeline_name=value, stage_name=value, pipeline_execution_id=value, retry_mode=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="retry_stage_execution",
        op_kwargs={
            "pipelineName": pipeline_name,
            "stageName": stage_name,
            "pipelineExecutionId": pipeline_execution_id,
            "retryMode": retry_mode,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, relational_database_name: str, password_version: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the current, previous, or pending versions of the master user password for a Lightsail database. The GetRelationalDatabaseMasterUserPassword operation supports tag-based access control via resource tags applied to the resource identified by relationalDatabaseName.

    Args:
        relational_database_name(str): The name of your database for which to get the master user password.
        password_version(str, optional): The password version to return. Specifying CURRENT or PREVIOUS returns the current or previous passwords respectively. Specifying PENDING returns the newest version of the password that will rotate to CURRENT. After the PENDING password rotates to CURRENT, the PENDING password is no longer available. Default: CURRENT . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.master_user_password.get(
                ctx, relational_database_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.master_user_password.get relational_database_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_relational_database_master_user_password",
        op_kwargs={
            "relationalDatabaseName": relational_database_name,
            "passwordVersion": password_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, job_flow_id: str, steps: List) -> Dict:
    r"""
    **Autogenerated function**

    AddJobFlowSteps adds new steps to a running cluster. A maximum of 256 steps are allowed in each job flow. If your cluster is long-running (such as a Hive data warehouse) or complex, you may require more than 256 steps to process your data. You can bypass the 256-step limitation in various ways, including using SSH to connect to the master node and submitting queries directly to the software running on the master node, such as Hive and Hadoop. For more information on how to do this, see Add More than 256 Steps to a Cluster in the Amazon EMR Management Guide. A step specifies the location of a JAR file stored either on the master node of the cluster or in Amazon S3. Each step is performed by the main function of the main class of the JAR file. The main class can be specified either in the manifest of the JAR or by using the MainFunction parameter of the step. Amazon EMR executes each step in the order listed. For a step to be considered complete, the main function must exit with a zero exit code and all Hadoop jobs started while the step was running must have completed and run successfully. You can only add steps to a cluster that is in one of the following states: STARTING, BOOTSTRAPPING, RUNNING, or WAITING.

    Args:
        job_flow_id(str): A string that uniquely identifies the job flow. This identifier is returned by RunJobFlow and can also be obtained from ListClusters. .
        steps(List):  A list of StepConfig to be executed by the job flow. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.job_flow.step.add(ctx, job_flow_id=value, steps=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.job_flow.step.add job_flow_id=value, steps=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="add_job_flow_steps",
        op_kwargs={"JobFlowId": job_flow_id, "Steps": steps},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub, ctx, fleet_arn: str, certificate: str, display_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Imports the root certificate of a certificate authority (CA) used to obtain TLS certificates used by associated websites within the company network.

    Args:
        fleet_arn(str): The ARN of the fleet.
        certificate(str): The root certificate of the CA.
        display_name(str, optional): The certificate name to display. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.website.certificate_authority.associate(
                ctx, fleet_arn=value, certificate=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.website.certificate_authority.associate fleet_arn=value, certificate=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="associate_website_certificate_authority",
        op_kwargs={
            "FleetArn": fleet_arn,
            "Certificate": certificate,
            "DisplayName": display_name,
        },
    )


async def describe(hub, ctx, fleet_arn: str, website_ca_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides information about the certificate authority.

    Args:
        fleet_arn(str): The ARN of the fleet.
        website_ca_id(str): A unique identifier for the certificate authority.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.website.certificate_authority.describe(
                ctx, fleet_arn=value, website_ca_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.website.certificate_authority.describe fleet_arn=value, website_ca_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="describe_website_certificate_authority",
        op_kwargs={"FleetArn": fleet_arn, "WebsiteCaId": website_ca_id},
    )


async def disassociate(hub, ctx, fleet_arn: str, website_ca_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes a certificate authority (CA).

    Args:
        fleet_arn(str): The ARN of the fleet.
        website_ca_id(str): A unique identifier for the CA.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.website.certificate_authority.disassociate(
                ctx, fleet_arn=value, website_ca_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.website.certificate_authority.disassociate fleet_arn=value, website_ca_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="disassociate_website_certificate_authority",
        op_kwargs={"FleetArn": fleet_arn, "WebsiteCaId": website_ca_id},
    )


async def list_all(
    hub, ctx, fleet_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of certificate authorities added for the current account and Region.

    Args:
        fleet_arn(str): The ARN of the fleet.
        max_results(int, optional): The maximum number of results to be included in the next page. Defaults to None.
        next_token(str, optional): The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.website.certificate_authority.list_all(
                ctx, fleet_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.website.certificate_authority.list_all fleet_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="list_website_certificate_authorities",
        op_kwargs={
            "FleetArn": fleet_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(
    hub, ctx, skill_id: str, parameter_key: str, room_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes room skill parameter details by room, skill, and parameter key ID.

    Args:
        room_arn(str, optional): The ARN of the room from which to remove the room skill parameter details. Defaults to None.
        skill_id(str): The ID of the skill from which to remove the room skill parameter details.
        parameter_key(str): The room skill parameter key for which to remove details.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.room.skill_parameter.delete(
                ctx, skill_id=value, parameter_key=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.room.skill_parameter.delete skill_id=value, parameter_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="delete_room_skill_parameter",
        op_kwargs={
            "RoomArn": room_arn,
            "SkillId": skill_id,
            "ParameterKey": parameter_key,
        },
    )


async def get(
    hub, ctx, skill_id: str, parameter_key: str, room_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets room skill parameter details by room, skill, and parameter key ARN.

    Args:
        room_arn(str, optional): The ARN of the room from which to get the room skill parameter details. . Defaults to None.
        skill_id(str): The ARN of the skill from which to get the room skill parameter details. Required.
        parameter_key(str): The room skill parameter key for which to get details. Required.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.room.skill_parameter.get(
                ctx, skill_id=value, parameter_key=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.room.skill_parameter.get skill_id=value, parameter_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="get_room_skill_parameter",
        op_kwargs={
            "RoomArn": room_arn,
            "SkillId": skill_id,
            "ParameterKey": parameter_key,
        },
    )


async def put(
    hub, ctx, skill_id: str, room_skill_parameter: Dict, room_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates room skill parameter details by room, skill, and parameter key ID. Not all skills have a room skill parameter.

    Args:
        room_arn(str, optional): The ARN of the room associated with the room skill parameter. Required. Defaults to None.
        skill_id(str): The ARN of the skill associated with the room skill parameter. Required.
        room_skill_parameter(Dict): The updated room skill parameter. Required.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.room.skill_parameter.put(
                ctx, skill_id=value, room_skill_parameter=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.room.skill_parameter.put skill_id=value, room_skill_parameter=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="put_room_skill_parameter",
        op_kwargs={
            "RoomArn": room_arn,
            "SkillId": skill_id,
            "RoomSkillParameter": room_skill_parameter,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    config_rule_names: List = None,
    compliance_types: List = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Indicates whether the specified AWS Config rules are compliant. If a rule is noncompliant, this action returns the number of AWS resources that do not comply with the rule. A rule is compliant if all of the evaluated resources comply with it. It is noncompliant if any of these resources do not comply. If AWS Config has no current evaluation results for the rule, it returns INSUFFICIENT_DATA. This result might indicate one of the following conditions:   AWS Config has never invoked an evaluation for the rule. To check whether it has, use the DescribeConfigRuleEvaluationStatus action to get the LastSuccessfulInvocationTime and LastFailedInvocationTime.   The rule's AWS Lambda function is failing to send evaluation results to AWS Config. Verify that the role you assigned to your configuration recorder includes the config:PutEvaluations permission. If the rule is a custom rule, verify that the AWS Lambda execution role includes the config:PutEvaluations permission.   The rule's AWS Lambda function has returned NOT_APPLICABLE for all evaluation results. This can occur if the resources were deleted or removed from the rule's scope.

    Args:
        config_rule_names(List, optional): Specify one or more AWS Config rule names to filter the results by rule. Defaults to None.
        compliance_types(List, optional): Filters the results by compliance. The allowed values are COMPLIANT and NON_COMPLIANT. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.compliance.by.config_rule.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.compliance.by.config_rule.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_compliance_by_config_rule",
        op_kwargs={
            "ConfigRuleNames": config_rule_names,
            "ComplianceTypes": compliance_types,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def get_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Gets the fine grained logging options.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.v2_logging.option.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.v2_logging.option.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="iot", operation="get_v2_logging_options", op_kwargs={}
    )


async def set_(
    hub,
    ctx,
    role_arn: str = None,
    default_log_level: str = None,
    disable_all_logs: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Sets the logging options for the V2 logging service.

    Args:
        role_arn(str, optional): The ARN of the role that allows IoT to write to Cloudwatch logs. Defaults to None.
        default_log_level(str, optional): The default logging level. Defaults to None.
        disable_all_logs(bool, optional): If true all logs are disabled. The default is false. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.v2_logging.option.set(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.v2_logging.option.set
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="set_v2_logging_options",
        op_kwargs={
            "roleArn": role_arn,
            "defaultLogLevel": default_log_level,
            "disableAllLogs": disable_all_logs,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    maintenance_track_name: str = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all the available maintenance tracks.

    Args:
        maintenance_track_name(str, optional): The name of the maintenance track. . Defaults to None.
        max_records(int, optional): An integer value for the maximum number of maintenance tracks to return. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeClusterTracks request exceed the value specified in MaxRecords, Amazon Redshift returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.track.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.track.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_cluster_tracks",
        op_kwargs={
            "MaintenanceTrackName": maintenance_track_name,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(hub, ctx, attribute: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns the settings for the specified account.

    Args:
        attribute(str):  The list of SettingAttribute enum values. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.setting.get_all(ctx, attribute=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.setting.get_all attribute=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="get_settings",
        op_kwargs={"attribute": attribute},
    )


async def update_multiple(
    hub,
    ctx,
    sns_topic: str = None,
    default_assessment_reports_destination: Dict = None,
    default_process_owners: List = None,
    kms_key: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates Audit Manager settings for the current user account.

    Args:
        sns_topic(str, optional):  The Amazon Simple Notification Service (Amazon SNS) topic to which Audit Manager sends notifications. . Defaults to None.
        default_assessment_reports_destination(Dict, optional):  The default storage destination for assessment reports. . Defaults to None.
        default_process_owners(List, optional):  A list of the default audit owners. . Defaults to None.
        kms_key(str, optional):  The KMS key details. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.setting.update_multiple(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.setting.update_multiple
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="update_settings",
        op_kwargs={
            "snsTopic": sns_topic,
            "defaultAssessmentReportsDestination": default_assessment_reports_destination,
            "defaultProcessOwners": default_process_owners,
            "kmsKey": kms_key,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def configure(
    hub,
    ctx,
    profiling_group_name: str,
    fleet_instance_id: str = None,
    metadata: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Used by profiler agents to report their current state and to receive remote configuration updates. For example, ConfigureAgent can be used to tell an agent whether to profile or not and for how long to return profiling data.

    Args:
        fleet_instance_id(str, optional):  A universally unique identifier (UUID) for a profiling instance. For example, if the profiling instance is an Amazon EC2 instance, it is the instance ID. If it is an AWS Fargate container, it is the container's task ID. . Defaults to None.
        metadata(Dict, optional):  Metadata captured about the compute platform the agent is running on. It includes information about sampling and reporting. The valid fields are:    COMPUTE_PLATFORM - The compute platform on which the agent is running     AGENT_ID - The ID for an agent instance.     AWS_REQUEST_ID - The AWS request ID of a Lambda invocation.     EXECUTION_ENVIRONMENT - The execution environment a Lambda function is running on.     LAMBDA_FUNCTION_ARN - The Amazon Resource Name (ARN) that is used to invoke a Lambda function.     LAMBDA_MEMORY_LIMIT_IN_MB - The memory allocated to a Lambda function.     LAMBDA_REMAINING_TIME_IN_MILLISECONDS - The time in milliseconds before execution of a Lambda function times out.     LAMBDA_TIME_GAP_BETWEEN_INVOKES_IN_MILLISECONDS - The time in milliseconds between two invocations of a Lambda function.     LAMBDA_PREVIOUS_EXECUTION_TIME_IN_MILLISECONDS - The time in milliseconds for the previous Lambda invocation.   . Defaults to None.
        profiling_group_name(str):  The name of the profiling group for which the configured agent is collecting profiling data. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.agent.init.configure(
                ctx, profiling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.agent.init.configure profiling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="configure_agent",
        op_kwargs={
            "fleetInstanceId": fleet_instance_id,
            "metadata": metadata,
            "profilingGroupName": profiling_group_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    web_acl_arn: str,
    rule_metric_name: str,
    scope: str,
    time_window: Dict,
    max_items: int,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets detailed information about a specified number of requests--a sample--that WAF randomly selects from among the first 5,000 requests that your Amazon Web Services resource received during a time range that you choose. You can specify a sample size of up to 500 requests, and you can specify any time range in the previous three hours.  GetSampledRequests returns a time range, which is usually the time range that you specified. However, if your resource (such as a CloudFront distribution) received 5,000 requests before the specified time range elapsed, GetSampledRequests returns an updated time range. This new time range indicates the actual period during which WAF selected the requests in the sample.

    Args:
        web_acl_arn(str): The Amazon resource name (ARN) of the WebACL for which you want a sample of requests.
        rule_metric_name(str): The metric name assigned to the Rule or RuleGroup for which you want a sample of requests.
        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   .
        time_window(Dict): The start date and time and the end date and time of the range for which you want GetSampledRequests to return a sample of requests. You must specify the times in Coordinated Universal Time (UTC) format. UTC format includes the special designator, Z. For example, "2016-09-27T14:50Z". You can specify any time range in the previous three hours. If you specify a start time that's earlier than three hours ago, WAF sets it to three hours ago.
        max_items(int): The number of requests that you want WAF to return from among the first 5,000 requests that your Amazon Web Services resource received during the time range. If your resource received fewer requests than the value of MaxItems, GetSampledRequests returns information about all of them. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.sampled_request.get_all(
                ctx,
                web_acl_arn=value,
                rule_metric_name=value,
                scope=value,
                time_window=value,
                max_items=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.sampled_request.get_all web_acl_arn=value, rule_metric_name=value, scope=value, time_window=value, max_items=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="get_sampled_requests",
        op_kwargs={
            "WebAclArn": web_acl_arn,
            "RuleMetricName": rule_metric_name,
            "Scope": scope,
            "TimeWindow": time_window,
            "MaxItems": max_items,
        },
    )
